@@ -1,7 +1,7 @@
 # main -----
 
 #' @export
-#' @title Tabulation of aggregations
+#' @title Create pivot-style summary tables
 #' @description It tabulates a data.frame representing an aggregation
 #' which is then transformed as a flextable with
 #' [as_flextable][as_flextable.tabulator]. The function
@@ -213,7 +213,7 @@ tabulator <- function(x, rows, columns,
 #' @param separate_with columns used to sepatate the groups
 #' with an horizontal line.
 #' @param big_border,small_border big and small border properties defined
-#' by a call to [fp_border_default()] or [fp_border()].
+#' by a call to [fp_border_default()] or [officer::fp_border()].
 #' @param rows_alignment,columns_alignment alignments to apply to
 #' columns corresponding to `rows` and `columns`; see arguments
 #' `rows` and `columns` in [tabulator()].
@@ -503,19 +503,26 @@ as_flextable.tabulator <- function(
       }
     }
   }
-  if (!is.null(x$n_by) && length(x$columns) == 1L) {
-    sum_x <- visible_columns
-    grp_labels <- sum_x[sum_x$.tab_columns %in% names(x$col_exprs)[1] & sum_x$.type. %in% "columns", x$columns]
-    col_keys <- sum_x[sum_x$.tab_columns %in% names(x$col_exprs)[1] & sum_x$.type. %in% "columns", "col_keys"]
-    names(col_keys) <- grp_labels
-    cts <- x$n_by$n
-    names(cts) <- x$n_by[[x$columns]]
-    for (lvl in names(cts)) {
-      ft <- append_chunks(
-        x = ft,
-        j = col_keys[lvl], i = 1, part = "header",
-        as_chunk(cts[lvl], formatter = fmt_header_n)
-      )
+  if (!is.null(x$n_by)) {
+    sum_x <- visible_columns[
+      visible_columns$.tab_columns %in% names(x$col_exprs)[1] &
+        visible_columns$.type. %in% "columns", , drop = FALSE
+    ]
+    header_row <- length(x$columns)
+
+    for (k in seq_len(nrow(x$n_by))) {
+      mask <- rep(TRUE, nrow(sum_x))
+      for (col in x$columns) {
+        mask <- mask & as.character(sum_x[[col]]) == as.character(x$n_by[[col]][k])
+      }
+      if (any(mask)) {
+        ft <- append_chunks(
+          x = ft,
+          j = sum_x[mask, "col_keys"][1],
+          i = header_row, part = "header",
+          as_chunk(x$n_by$n[k], formatter = fmt_header_n)
+        )
+      }
     }
   }
 
@@ -750,6 +757,10 @@ map_visible_columns <- function(dat, columns, rows, value_names = character(0),
   sel_columns <- columns[seq_len(length(columns) - 2)]
 
   for (j in rev(seq_along(sel_columns))) {
+    # Check if any group has more than 1 row (only then do we need separators)
+    group_sizes <- table(rleid(ldims[[j]]))
+    if (all(group_sizes <= 1)) next
+
     ldims <- split(ldims, rleid(ldims[[j]]))
     ldims <- lapply(ldims, function(x, j) {
       x[nrow(x), j] <- "dummy"
