@@ -1,3 +1,27 @@
+#' @export
+#' @title Apply borderless theme
+#' @description Apply theme borderless to a flextable.
+#' All borders are removed. Header text is bold,
+#' text columns are left aligned, other columns are
+#' right aligned.
+#' @inheritParams args_x_only
+#' @family functions related to themes
+#' @inheritSection theme_vanilla behavior
+#' @examples
+#' ft <- flextable(head(airquality))
+#' ft <- theme_borderless(ft)
+#' ft
+theme_borderless <- function(x) {
+  if (!inherits(x, "flextable")) {
+    stop(sprintf("Function `%s` supports only flextable objects.", "theme_borderless()"))
+  }
+  x <- border_remove(x)
+  x <- bold(x = x, bold = TRUE, part = "header")
+  x <- align_text_col(x, align = "left", header = TRUE)
+  x <- align_nottext_col(x, align = "right", header = TRUE)
+  x
+}
+
 #' @importFrom officer fp_border fp_par
 #' @export
 #' @title Apply vanilla theme
@@ -29,7 +53,7 @@
 #' to be applied systematically before the `flextable()` is printed;
 #' in this case, don't forget to take care that the theme doesn't
 #' override any formatting done before the print statement.
-#' @param x a flextable object
+#' @inheritParams args_x_only
 #' @family functions related to themes
 #' @examples
 #' ft <- flextable(head(airquality))
@@ -40,7 +64,7 @@ theme_vanilla <- function(x) {
     stop(sprintf("Function `%s` supports only flextable objects.", "theme_vanilla()"))
   }
 
-  std_b <- fp_border(width = flextable_global$defaults$border.width*2, color = flextable_global$defaults$border.color)
+  std_b <- fp_border(width = flextable_global$defaults$border.width * 2, color = flextable_global$defaults$border.color)
   thin_b <- fp_border(width = flextable_global$defaults$border.width, color = flextable_global$defaults$border.color)
 
   x <- border_remove(x)
@@ -59,7 +83,7 @@ theme_vanilla <- function(x) {
 #' @export
 #' @title Apply box theme
 #' @description Apply theme box to a flextable
-#' @param x a flextable object
+#' @inheritParams args_x_only
 #' @family functions related to themes
 #' @inheritSection theme_vanilla behavior
 #' @examples
@@ -93,7 +117,7 @@ theme_box <- function(x) {
 #' @export
 #' @title Apply alafoli theme
 #' @description Apply alafoli theme
-#' @param x a flextable object
+#' @inheritParams args_x_only
 #' @family functions related to themes
 #' @inheritSection theme_vanilla behavior
 #' @examples
@@ -127,7 +151,7 @@ theme_alafoli <- function(x) {
 #' @export
 #' @title Apply Sith Lord Darth Vader theme
 #' @description Apply Sith Lord Darth Vader theme to a flextable
-#' @param x a flextable object
+#' @inheritParams args_x_only
 #' @param ... unused
 #' @family functions related to themes
 #' @inheritSection theme_vanilla behavior
@@ -147,7 +171,7 @@ theme_vader <- function(x, ...) {
   x <- bold(x = x, bold = TRUE, part = "header")
   x <- italic(x = x, italic = FALSE, part = "all")
 
-  big_border <- fp_border(color = "#ff0000", width = flextable_global$defaults$border.width*2)
+  big_border <- fp_border(color = "#ff0000", width = flextable_global$defaults$border.width * 2)
 
   h_nrow <- nrow_part(x, "header")
   b_nrow <- nrow_part(x, "body")
@@ -172,7 +196,7 @@ theme_vader <- function(x, ...) {
 #' @export
 #' @title Apply zebra theme
 #' @description Apply theme zebra to a flextable
-#' @param x a flextable object
+#' @inheritParams args_x_only
 #' @param odd_header,odd_body,even_header,even_body odd/even colors for table header and body
 #' @family functions related to themes
 #' @inheritSection theme_vanilla behavior
@@ -225,7 +249,7 @@ theme_zebra <- function(x, odd_header = "#CFCFCF", odd_body = "#EFEFEF",
 #' @export
 #' @title Apply tron legacy theme
 #' @description Apply theme tron legacy to a flextable
-#' @param x a flextable object
+#' @inheritParams args_x_only
 #' @family functions related to themes
 #' @inheritSection theme_vanilla behavior
 #' @examples
@@ -267,7 +291,7 @@ theme_tron_legacy <- function(x) {
 #' @export
 #' @title Apply tron theme
 #' @description Apply theme tron to a flextable
-#' @param x a flextable object
+#' @inheritParams args_x_only
 #' @family functions related to themes
 #' @inheritSection theme_vanilla behavior
 #' @examples
@@ -309,7 +333,7 @@ theme_tron <- function(x) {
 #' @export
 #' @title Apply booktabs theme
 #' @description Apply theme booktabs to a flextable
-#' @param x a flextable object
+#' @inheritParams args_x_only
 #' @param bold_header header will be bold if TRUE.
 #' @param ... unused
 #' @family functions related to themes
@@ -323,8 +347,10 @@ theme_booktabs <- function(x, bold_header = FALSE, ...) {
     stop(sprintf("Function `%s` supports only flextable objects.", "theme_booktabs()"))
   }
 
-  big_border <- fp_border(width = flextable_global$defaults$border.width*2,
-                          color = flextable_global$defaults$border.color)
+  big_border <- fp_border(
+    width = flextable_global$defaults$border.width * 2,
+    color = flextable_global$defaults$border.color
+  )
   std_border <- update(big_border, width = flextable_global$defaults$border.width)
 
   h_nrow <- nrow_part(x, "header")
@@ -360,12 +386,12 @@ theme_booktabs <- function(x, bold_header = FALSE, ...) {
 #' @title Apply APA theme
 #' @description Apply theme APA (the stylistic style of the American
 #'              Psychological Association) to a flextable
-#' @param x a flextable object
+#' @inheritParams args_x_only
 #' @param ... unused
 #' @family functions related to themes
 #' @inheritSection theme_vanilla behavior
 #' @examples
-#' ft <- flextable(head(mtcars*22.22))
+#' ft <- flextable(head(mtcars * 22.22))
 #' ft <- theme_apa(ft)
 #' ft
 theme_apa <- function(x, ...) {
